#!/bin/bash

set -eu -o pipefail

fqdn=$(hostname -f)

chown -R cloudron.cloudron /app/data

# Dockerfile changes the ownership of this file to make it writable by cloudron user
sed -e "s/^Port .*/Port ${SSH_PORT}/" \
    -e "s/^#ListenAddress .*/ListenAddress 0.0.0.0/" \
    -i /etc/ssh/sshd_config

/usr/bin/supervisord --configuration /etc/supervisor/supervisord.conf --nodaemon -i Gogs &

sleep 3

if [[ ! -f /home/cloudron/gogs/custom/conf/app.ini ]]; then
    echo "Triggering installation"

    mkdir -p /home/cloudron/gogs/custom/conf
    touch /home/cloudron/gogs/custom/conf/app.ini
    chown cloudron:cloudron /home/cloudron/gogs/custom/conf/app.ini

    admin_password=$(pwgen -1)
    echo "Admin password set to ${admin_password}"

    # this creates the custom/conf/app.ini
    curl -X POST http://localhost:3000/install \
        --data db_type=MySQL \
        --data-urlencode "db_host=${MYSQL_HOST}:${MYSQL_PORT}" \
        --data "db_user=${MYSQL_USERNAME}" \
        --data-urlencode "db_passwd=${MYSQL_PASSWORD}" \
        --data "db_name=${MYSQL_DATABASE}" \
        --data-urlencode "repo_root_path=/tmp" \
        --data run_user=cloudron \
        --data "domain=${fqdn}" \
        --data http_port=3000 \
        --data-urlencode "app_url=https://${fqdn}/" \
        --data "smtp_host=${MAIL_SMTP_SERVER}" \
        --data smtp_user= \
        --data smtp_pwd= \
        --data admin_name=administrator \
        --data admin_passwd=${admin_password} \
        --data admin_confirm_passwd=${admin_password} \
        --data-urlencode admin_email=girish@forwardbias.in
fi

# use GOGS_CONFIG maybe for this but not very documented
sed -e "s/##HOSTNAME/${fqdn}/g" \
    -e "s/##SSH_PORT/${SSH_PORT}/g" \
    -e "s/##MYSQL_HOST/${MYSQL_HOST}/g" \
    -e "s/##MYSQL_PORT/${MYSQL_PORT}/g" \
    -e "s/##MYSQL_USERNAME/${MYSQL_USERNAME}/g" \
    -e "s/##MYSQL_PASSWORD/${MYSQL_PASSWORD}/g" \
    -e "s/##MYSQL_DATABASE/${MYSQL_DATABASE}/g" \
    -e "s/##MAIL_SERVER/${MAIL_SMTP_SERVER}/g" \
    -e "s/##MAIL_PORT/${MAIL_SMTP_PORT}/g" \
    -e "s/##MAIL_FROM/${MAIL_SMTP_USERNAME}@${MAIL_DOMAIN}/g" \
    -e "s/##SECRET_KEY/$(pwgen -1 -s)/g" \
    /home/cloudron/app.ini.template > "/home/cloudron/gogs/custom/conf/app.ini"

# update ldap (won't work without _csrf)
#curl -X POST http://localhost:3000/admin/auths/1 \
#    --data id=1 \
#    --data type=2 \
#    --data name=cloudron \
#    --data domain=cloudron \
#    --data host=${LDAP_SERVER} \
#    --data port=${LDAP_PORT} \
#    --data-urlencode base_dn=ou=users,dc=cloudron \
#    --data attribute_username=uid \
#    --data attribute_name= \
#    --data attribute_surname= \
#    --data attribute_mail=mail \
#    --data-urlencode 'filter=(&(objectClass=user)(uid=%s))' \
#    --data ms_ad_sa= \
#    --data is_actived=on

# id, type, name, is_actived, cfg, allow_auto_register, created, updated
mysql -u"${MYSQL_USERNAME}" -p"${MYSQL_PASSWORD}" -h mysql --database="${MYSQL_DATABASE}" \
    -e "REPLACE INTO login_source VALUES (1,2,'cloudron',1,'{\"Name\":\"cloudron\",\"Host\":\"${LDAP_SERVER}\",\"Port\":${LDAP_PORT},\"UseSSL\":false,\"BaseDN\":\"${LDAP_USERS_BASE_DN}\",\"AttributeUsername\":\"uid\",\"AttributeName\":\"\",\"AttributeSurname\":\"\",\"AttributeMail\":\"mail\",\"Filter\":\"(\\\\u0026(objectClass=user)(uid=%s))\",\"MsAdSAFormat\":\"cn=%s,${LDAP_USERS_BASE_DN}\",\"Enabled\":true}',0,'2015-06-24 17:14:12','2015-06-24 17:25:03');"

supervisorctl restart gogs

wait

